@@ -347,7 +347,7 @@ def reproject(in_images, out_images, header=None, bitpix=None,
         os.mkdir(os.path.join(final_dir, '%i' % i))
 
         mProject_auto(in_images[i], os.path.join(final_dir, '%i' % i, 'image_tmp.fits'),
-                      header_hdr, hdu=hdu)
+                      header_hdr, hdu=hdu, factor=factor)
 
         if exact_size:
             m.mImgtbl(os.path.join(final_dir, '%i' % i), images_tmp_tbl, corners=True)
@@ -418,7 +418,7 @@ def mosaic(input_dir, output_dir, header=None, image_table=None, mpi=False,
         Whether to remove any temporary directories used for mosaicking
 
     bitpix : int, optional
-        BITPIX value for the ouput FITS file (default is -64). Possible
+        BITPIX value for the ouput FITS file (default is -32). Possible
         values are: 8 (character or unsigned binary integer), 16 (16-bit
         integer), 32 (32-bit integer), -32 (single precision floating
         point), -64 (double precision floating point).
